@@ -25,12 +25,12 @@ class ScriptLoader(nose.plugins.Plugin):
 
         Attempt to load the file using :func:`imp.load_source`. If that
         succeeds, pass the loaded module to the :attr:`loader`
-        :meth:`loadTestsFromModule`. If the file can't be loaded, return False
+        :meth:`loadTestsFromModule`. If the file can't be loaded, return None
         so other plugins can try loading it.
         """
         try:
             module = imp.load_source("module", filename)
         except SyntaxError:
-            return False
+            return None
 
         return self.loader.loadTestsFromModule(module)
